==> Guppi-0.34.4.tar.gz: Guppi-0.34.4/plug-ins/plot/axis/init.c <==
/* $Id: init.c,v 1.1 2000/04/07 18:32:41 trow Exp $ */

/*
 * init.c
 *
 * Copyright (C) 2000 EMC Capital Management, Inc.
 *
 * Developed by Jon Trowbridge <trow@gnu.org>.

 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

#include <config.h>
#include <guppi-plot-plug-in.h>
#include "guppi-axis-element.h"
/* #include "guppi-scm-axis.h" */

GuppiPlugIn* guppi_plug_in(void);

static GuppiPlotElement*
make_element(void)
{
  return guppi_axis_element_new();
}

GuppiPlugIn*
guppi_plug_in(void)
{
  GuppiPlugIn* pi;
  GuppiPlotPlugIn* ppi;

  pi = guppi_plot_plug_in_new();
  ppi = GUPPI_PLOT_PLUG_IN(pi);

  pi->magic_number = GUPPI_PLUG_IN_MAGIC_NUMBER;
  pi->type = "plot";
  pi->external_name = _("Axis");
  pi->internal_name = "axis";
  pi->major_version = GUPPI_MAJOR_VERSION;
  pi->minor_version = GUPPI_MINOR_VERSION;
  pi->micro_version = GUPPI_MICRO_VERSION;
  pi->copyright = "(C) 2000 EMC Capital Management, Inc.";
  pi->authors = "Jon Trowbridge <trow@gnu.org>";

  ppi->element_constructor = make_element;

  /* guppi_scm_axis_init(); */

  /* Do any other necessary initialization here. */
  
  return pi;
}





/* $Id: init.c,v 1.1 2000/04/07 18:32:41 trow Exp $ */

==> Guppi-0.35.1.tar.gz: Guppi-0.35.1/plug-ins/plot/axis/init.c <==
/* $Id: init.c,v 1.8 2000/10/20 01:21:29 trow Exp $ */

/*
 * init.c
 *
 * Copyright (C) 2000 EMC Capital Management, Inc.
 *
 * Developed by Jon Trowbridge <trow@gnu.org>.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

#include <config.h>
#include <guppi-scripting.h>
#include <guppi-plot-plug-in.h>
#include "guppi-axis-state.h"
#include "guppi-scm-axis.h"
#ifdef HAVE_PYTHON
#include "guppi-python-axis.h"
#endif

GuppiPlugIn *guppi_plug_in (void);

static GuppiElementState *
make_element (void)
{
  return guppi_axis_state_new ();
}

GuppiPlugIn *
guppi_plug_in (void)
{
  GuppiPlugIn *pi;
  GuppiPlotPlugIn *ppi;

  pi = guppi_plot_plug_in_new ();
  ppi = GUPPI_PLOT_PLUG_IN (pi);

  pi->magic_number = GUPPI_PLUG_IN_MAGIC_NUMBER;
  ppi->element_constructor = make_element;

  if (guppi_supports_guile ())
    guppi_scm_axis_init ();
#ifdef HAVE_PYTHON
  if (guppi_supports_python ())
    guppi_python_axis_init ();
#endif

  /* Do any other necessary initialization here. */

  return pi;
}





/* $Id: init.c,v 1.8 2000/10/20 01:21:29 trow Exp $ */
